@@ -41,6 +41,9 @@ _configure() {
     ${unicode_enabled} \
             && configure_args+=( CPPFLAGS='-DXML_UNICODE -DXML_UNICODE_WCHAR_T' )
 
+    ${xml_attr_info_enabled} \
+            && configure_args+=( --enable-xml-attr-info )
+
     if [[ ${xml_context} -eq 0 ]]; then
         configure_args+=( --disable-xml-context )
     else
@@ -110,8 +113,8 @@ _run() {
         cd "${build_dir}"
 
         _configure \
-                CFLAGS="${BASE_FLAGS}" \
-                CXXFLAGS="${BASE_FLAGS}"
+                CFLAGS="${CFLAGS}" \
+                CXXFLAGS="${CXXFLAGS}"
 
         (
             set -x
@@ -211,8 +214,10 @@ _main() {
                 continue
             fi
 
-            for xml_context in 0 1024 ; do
-                _build_case
+            for xml_attr_info_enabled in true false ; do
+                for xml_context in 0 1024 ; do
+                    _build_case
+                done
             done
         done
     done
